Changelog
=========

1.1.1 | 2025-12-15
------------------

* updated metadata links and extended tests (`#14 <https://github.com/SAR-ARD/cesard/pull/14>`_)

`Full v1.1.1 Changelog <https://github.com/SAR-ARD/cesard/compare/v1.1.0...v1.1.1>`_

1.1.0 | 2025-12-12
------------------

* software version tracking (`#12 <https://github.com/SAR-ARD/cesard/pull/12>`_)
* improve handling of DEMs in EPSG:4326 (`#8 <https://github.com/SAR-ARD/cesard/pull/8>`_)

`Full v1.1.0 Changelog <https://github.com/SAR-ARD/cesard/compare/v1.0.3...v1.1.0>`_

1.0.3 | 2025-12-09
------------------

* [README] add badges (`#10 <https://github.com/SAR-ARD/cesard/pull/10>`_)
* metadata type evaluation (`#9 <https://github.com/SAR-ARD/cesard/pull/9>`_)

`Full v1.0.3 Changelog <https://github.com/SAR-ARD/cesard/compare/v1.0.2...v1.0.3>`_

1.0.2 | 2025-11-21
------------------

* removed S1-specific functions, added modern typing (`#5 <https://github.com/SAR-ARD/cesard/pull/5>`_)
* dem.retile: use truly unique file names for VRTs and delete them once done (`#6 <https://github.com/SAR-ARD/cesard/pull/6>`_)

`Full v1.0.2 Changelog <https://github.com/SAR-ARD/cesard/compare/v1.0.1...v1.0.2>`_

1.0.1 | 2025-11-02
------------------

* documentation improvements (`#2 <https://github.com/SAR-ARD/cesard/pull/2>`_)
* metadata improvements (`#3 <https://github.com/SAR-ARD/cesard/pull/3>`_)

`Full v1.0.1 Changelog <https://github.com/SAR-ARD/cesard/compare/v1.0.0...v1.0.1>`_

1.0.0 | 2025-10-27
------------------

outsourced from `s1ard <https://github.com/SAR-ARD/s1ard>`_ version 2.5.0.
